%global ansible_collection_files %{_datadir}/ansible/collections/ansible_collections/performancecopilot


Summary:          Ansible roles for the Performance Co-Pilot toolkit
Name:             ansible-pcp
Version:          2.2.9
Release:          2%{?dist}
License:          MIT
URL:              https://github.com/performancecopilot/ansible-pcp
Source0:          https://github.com/performancecopilot/ansible-pcp/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:        noarch
Requires:         ansible

%description
A collection containing roles for Performance Co-Pilot (PCP) and related
software such as Redis and Grafana.  The collection is made up of several
Ansible roles, including:

*performancecopilot.metrics.pcp
A role for core PCP capabilities, configuring live performance analysis
with a large base set of metrics from the kernel and system services, as
well as data recording and rule inference.

*performancecopilot.metrics.redis
A role for configuring a local Redis server, suitable for use with a
Performance Co-Pilot archive repository (for single or many hosts) and
fast, scalable querying of metrics.


*performancecopilot.metrics.grafana
A role for configuring a local Grafana server, providing web frontend
visuals for Performance Co-Pilot metrics, both live and historically.
Data sources for Vector (live), Redis (historical) and interactive
bpftrace (eBPF) scripts can be configured by this role.  The PCP REST
API service (from the core pcp role) should be configured in order to
use this role.

*performancecopilot.metrics.bpftrace
A role that extends the core PCP role, providing metrics from bpftrace
scripts using Linux eBPF facilities.  Configuring authentication of a
local user capable of running bpftrace scripts via the PCP agent is a
key task of this role.

*performancecopilot.metrics.elasticsearch
A role that extends the core PCP role, providing metrics from a live
ElasticSearch instance for PCP analysis or exporting of PCP metric
values (and metadata) to ElasticSearch for the indexing and querying
of performance data.


%prep
%autosetup
mv .yamllint.yml yamllint.yml
rm -vr roles/repository tests/*repository* tests/*/*repository* docs/repository
rm -vr .github .gitignore .ansible-lint
sed -i \
    -e 's/^name: .*/name: %{collection_name}/g' \
    -e 's/^namespace: .*/namespace: %{collection_namespace}/g' \
    galaxy.yml
find . -name \*.yml -o -name \*.md | while read file; do
    sed -i \
        -e 's/performancecopilot.metrics/performancecopilot.metrics/g' \
    $file
done


%build
tar -cf %{_tmppath}/performancecopilot-metrics-%{version}.tar.gz .


%install
mkdir -p %{buildroot}%{ansible_collection_files}/metrics
cd %{buildroot}%{ansible_collection_files}/metrics
tar -xf %{_tmppath}/performancecopilot-metrics-%{version}.tar.gz


%check
mv yamllint.yml .yamllint.yml


%files
%doc README.md
%license LICENSE
%{ansible_collection_files}


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.9-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jul 19 2023 kianli <kianli@tencent.com> - 2.2.9-1
- Upgrade to 2.2.9

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.7-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.7-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 23 2023 Miaojun Dong <zoedong@tencent.com> - 2.2.7-2
- remove README.md

* Wed Nov 30 2022 rockerzhu <rockerzhu@tencent.com> - 2.2.7-1
- Initial build
